import Ember from "ember";
import CodeMirror from "codemirror";

export default Ember.Component.extend({

	tagName: 'div',

	value: '',

	classNames: ['editable-code'],

	// ------------------------------
	// Set codemirror options
	// ------------------------------

	autoCloseBrackets: true,
	autofocus: false,
	commentBlankLines: false,
	cursorBlinkRate: 530,
	electricChars: true,
	extraKeys: { 'Cmd-/': 'toggleComment', 'Cmd-Alt-/': 'blockComment' },
	firstLineNumber: 1,
	historyEventDelay: 1250,
	indentUnit: 4,
	indentWithTabs: false,
	lineNumbers: true,
	lineWrapping: false,
	matchBrackets: true,
	mode: 'javascript',
	readOnly: false,
	smartIndent: true,
	tabSize: 4,
	theme: 'abcum',
	undoDepth: 200,
	viewportMargin: 10,

	// ------------------------------
	// Set codemirror editor
	// ------------------------------

	didReceiveAttrs() {

		this._super(...arguments);

		let value = this.get('value');

		if (this.editor && this.editor.getValue() !== value) {
			this.editor.setValue(value);
		}

	},

	didInsertElement() {

		this._super(...arguments);

		let options = this.getProperties([
			'value',
			'autoCloseBrackets',
			'autofocus',
			'commentBlankLines',
			'cursorBlinkRate',
			'electricChars',
			'extraKeys',
			'firstLineNumber',
			'historyEventDelay',
			'indentUnit',
			'indentWithTabs',
			'lineNumbers',
			'lineWrapping',
			'matchBrackets',
			'mode',
			'readOnly',
			'smartIndent',
			'tabSize',
			'theme',
			'undoDepth',
			'viewportMargin',
		]);

		this.editor = new CodeMirror(this.element, options);

		this.editor.on('change', (instance) => {
			this.sendAction('on-change', instance.getValue());
		});

	},

});
